@@ -50,7 +50,7 @@ $lang = array_merge($lang, array(
 	'SYSTEM_TIMEZONE_EXPLAIN'			=> 'เขตเวลาใช้่เพื่อแสดงเวลาสำหรับบุคคลทั่วไป รวมทั้งบอท ด้วย ซึ่งไม่ใช่สมาชิกที่ เข้าสู่ระบบ. สมาชิกที่เข้าสู่ระบบแล้วสามารถตั้งค่าเขตเวลาของตัวเองได้ที่ user control panel.',
 	
 	'WARNINGS_EXPIRE'				=> 'ระยะเวลาการเตือน',
-	'WARNINGS_EXPIRE_EXPLAIN'		=> 'จำนวนวัน ก่อนที่ตำเตือนจะหมดอายุโดยอัตโนมัติ',
+	'WARNINGS_EXPIRE_EXPLAIN'		=> 'จำนวนวัน ก่อนที่ตำเตือนจะหมดอายุโดยอัตโนมัติ ตั้งค่านี้เป็น 0 เพื่อใช้คำเตือนอย่างถาวร',
 ));
 
 // Board Features
@@ -187,7 +187,7 @@ $lang = array_merge($lang, array(
 	'MAX_POST_URLS_EXPLAIN'			=> 'จำนวนลิงค์สูงสุดใน 1 โพสต์ ตั้งค่าเป็น 0 เพื่อไม่จำกัดจำนวนลิงค์',
 
 	'MIN_CHAR_LIMIT'				=> 'จำนวนตัวอักษรน้อยสุดต่อ การโพสต์/ข้อความ',
-	'MIN_CHAR_LIMIT_EXPLAIN'		=> 'จำนวนตัวอีกษรน้อยสุดที่ผู้ใช้ต้องใส่ในการโพสต์หรือส่ง pm.',
+	'MIN_CHAR_LIMIT_EXPLAIN'		=> 'จำนวนตัวอีกษรน้อยสุดที่ผู้ใช้ต้องใส่ในการโพสต์หรือส่ง pm. ค่าน้อยที่สุดคือ 1 ตัวอักษร',
 	
 	'POSTING'						=> 'การโพสต์',
 	'POSTS_PER_PAGE'				=> 'โพสต์ต่อหนึ่งหน้า',
