@@ -1,6 +1,6 @@
 <?php
 /** 
-* ภาษาไทย เวอร์ชั่น 1.1.3 
+* ภาษาไทย เวอร์ชั่น 1.2.3 
 * 23/11/2553  
 * ไฟล์ภาษาไทยสำหรับ PHPBB3 โดย www.mindphp.com และ www.phpbbthailand.com
 *
@@ -340,6 +340,17 @@ $lang = array_merge($lang, array(
 	'DATABASE_SERVER_INFO'	=> 'ข้อมูล ฐานข้อมูล เซิร์ฟเวอร์',
 	'DATABASE_SIZE'			=> 'ขนาดฐานข้อมูล',
 
+// Enviroment configuration checks, mbstring related
+	'ERROR_MBSTRING_FUNC_OVERLOAD'					=> 'ฟังก์ชั่น overloading ถูกกำหนดค่าไม่ถูกต้อง',
+	'ERROR_MBSTRING_FUNC_OVERLOAD_EXPLAIN'			=> '<var>mbstring.func_overload</var> จำเป็นต้องเป็นค่า 0 หรือ 4. สามารถเช็คค่าที่ตั้งไว้ตอนนี้ได้ที่หน้า  <samp>ข้อมูล PHP</samp>.',
+	'ERROR_MBSTRING_ENCODING_TRANSLATION'			=> 'Transparent character encoding ถูกกำหนดไว้ไม่ถูกต้อง',
+	'ERROR_MBSTRING_ENCODING_TRANSLATION_EXPLAIN'	=> '<var>mbstring.encoding_translation</var> จำเป็นต้องตั้งเป็น 0. สามารถเช็คค่าที่ตั้งไว้ตอนนี้ได้ที่หน้า  <samp>ข้อมูล PHP</samp>.',
+	'ERROR_MBSTRING_HTTP_INPUT'						=> 'HTTP input character conversion is improperly configured',
+	'ERROR_MBSTRING_HTTP_INPUT_EXPLAIN'				=> '<var>mbstring.http_input</var> ต้องถูกกำหนดหเป็น <samp>pass</samp>. สามารถเช็คค่าที่ตั้งไว้ตอนนี้ได้ที่หน้า  <samp>ข้อมูล PHP</samp>.',
+	'ERROR_MBSTRING_HTTP_OUTPUT'					=> 'HTTP output character conversion is improperly configured',
+	'ERROR_MBSTRING_HTTP_OUTPUT_EXPLAIN'			=> '<var>mbstring.http_output</var> ต้องถูกกำหนดหเป็น <samp>pass</samp>. สามารถเช็คค่าที่ตั้งไว้ตอนนี้ได้ที่หน้า  <samp>ข้อมูล PHP</samp>.',
+
+
 	'FILES_PER_DAY'		=> 'ไฟล์แนบต่อวัน',
 	'FORUM_STATS'		=> 'สถิติต่างๆของบอร์ด',
 
