@@ -145,6 +145,7 @@ $lang = array_merge($lang, array(
 	'EMPTY_MESSAGE_SUBJECT'				=> 'กรุณากรอกข้อความด้วย',
 	'ENABLED'							=> 'เปิดใช้งาน',
 	'ENCLOSURE'							=> 'ปิดการใช้งาน',
+	'ENTER_USERNAME'					=> 'กรอกชื่อผู้ใช้',
 	'ERR_CHANGING_DIRECTORY'			=> 'ไม่สามารถเปลี่ยนไดเรกทอรี่ได้',
 	'ERR_CONNECTING_SERVER'				=> 'ไม่สามารถเชื่อมต่อกับเซิร์ฟเวอร์ได้',
 	'ERR_JAB_AUTH'						=> 'Could not authorise on Jabber server.',
@@ -180,7 +181,7 @@ $lang = array_merge($lang, array(
 	'FORUM_RULES_LINK'		=> 'กรุณาอ่านกฏการใช้งานบอร์ด',
 	'FROM'					=> 'จาก',
 	'FSOCK_DISABLED'		=> 'การทำงานนี้ไม่ถูกต้องเพราะ <var>fsockopen</var> ฟังก์ชันไม่สามารถทำงานได้หรือเซิร์ฟเวอร์ค้นหาไม่พบ',
-
+	'FSOCK_TIMEOUT'			=> 'timeout ในขณะอ่านข้อมูลจากเครือข่าย ',
 	'FTP_FSOCK_HOST'				=> 'FTP โฮสต์',
 	'FTP_FSOCK_HOST_EXPLAIN'		=> 'FTP โฮสต์ ถูกเชื่อมต่อด้วยเซิร์ฟเวอร์ของคุณ',
 	'FTP_FSOCK_PASSWORD'			=> 'รหัสผ่าน FTP',
@@ -304,7 +305,7 @@ $lang = array_merge($lang, array(
 	'LOGIN_VIEW_FORUM'					=> 'เวบบอร์ดนี้ต้องการการลงทะเบียนและการเข้าใช้งานในระบบ สำหรับดูข้อความในบอร์ดนี้',
 	'LOGIN_EXPLAIN_EDIT'				=> 'ในการแก้ไขข้อความในบอร์ดนี้ คุณต้องลงทะเบียนการเป็นสมาชิกและเข้าใช้งานในระบบก่อน',
 	'LOGIN_EXPLAIN_VIEWONLINE'			=> 'ในการดูข้อความในบอร์ดนี้ คุณต้องลงทะเบียนการเป็นสมาชิกและเข้าใช้งานในระบบก่อน',
-	'TRANSLATION_INFO'	=> 'Thai language by <a href="http://www.phpbbthailand.com" target="_blank">phpBBThailand.com</a>',	
+	'TRANSLATION_INFO'	=> 'Thai language by <a href="http://www.mindphp.com" target="_blank">Mindphp.com</a> &amp; <a href="http://www.phpbbthailand.com" target="_blank">phpBBThailand.com</a>',	
 	'LOGOUT'							=> 'ออกจากระบบ',
 	'LOGOUT_USER'						=> 'สวัสดี %s [<strong>ออกจากระบบ</strong>]',
 	'LOG_ME_IN'							=> 'เข้าสู่ระบบอัตโนมัติ',
@@ -657,6 +658,12 @@ $lang = array_merge($lang, array(
 	'UNREAD_PMS'			=> '<strong>%d</strong> ข้อความยังไม่ได้อ่าน',
 	'UNREAD_POST'			=> 'โพสที่ยังไม่ได้อ่าน',
 	'UNREAD_POSTS'			=> 'หลายโพสที่ยังไม่ได้อ่าน',	
+
+	'UNWATCH_FORUM_CONFIRM'		=> 'คุณต้องการยกเลิกการแจ้งเตือนที่บอร์ดนี้ ?',
+	'UNWATCH_FORUM_DETAILED'	=> 'คุณต้องการยกเลิกการแจ้งเตือนที่บอร์ดนี้ “%s”?',
+	'UNWATCH_TOPIC_CONFIRM'		=> 'คุณต้องการยกเลิกการแจ้งเตือนที่กระทู้นี้ ?',
+	'UNWATCH_TOPIC_DETAILED'	=> 'คุณต้องการยกเลิกการแจ้งเตือนที่กระทู้ “%s” ?',
+		
 	'UNWATCHED_FORUMS'		=> 'คุณไม่สามารถเผ้าดู บอร์ด นี้ได้',
 	'UNWATCHED_TOPICS'		=> 'คุณไม่สามารถเผ้าดูกระทู้นี้ได้',
 	'UNWATCHED_FORUMS_TOPICS'	=> 'คุณไม่มีสิทธิ์เข้าใช้งานในบอร์ด นี้',
@@ -706,6 +713,12 @@ $lang = array_merge($lang, array(
 
 	'WARNINGS'			=> 'คำเตือน',
 	'WARN_USER'			=> 'เตือนผู้ใช้งาน',
+
+	'WATCH_FORUM_CONFIRM'	=> 'คุณต้องการรับการแจ้งเตือนมเมื่อมีโพสต์ใหม่ที่บอร์ดนี้ ?',
+	'WATCH_FORUM_DETAILED'	=> 'คุณต้องการรับการแจ้งเตือนมเมื่อมีโพสต์ใหม่ที่บอร์ด “%s”?',
+	'WATCH_TOPIC_CONFIRM'	=> 'คุณต้องการรับการแจ้งเตือนมเมื่อมีโพสต์ใหม่ที่กระทู้นี้ ?',
+	'WATCH_TOPIC_DETAILED'	=> 'คุณต้องการรับการแจ้งเตือนมเมื่อมีโพสต์ใหม่ที่กระทู้ “%s”?',
+		
 	'WELCOME_SUBJECT'	=> 'ยินดีต้อนรับบอร์ด %s ',
 	'WEBSITE'			=> 'เว็บไซต์',
 	'WHOIS'				=> 'Whois',
