@@ -1,7 +1,7 @@
 <?php
 /** 
-* ภาษาไทย เวอร์ชั่น 1.2.0 
-* 23/11/2553 
+* ภาษาไทย เวอร์ชั่น 1.3.0 
+* 06/01/2555 
 * ไฟล์ภาษาไทยสำหรับ PHPBB3 โดย www.mindphp.com และ www.phpbbthailand.com
 *
 */ 
@@ -346,12 +346,16 @@ $help = array(
 		1 => 'เกี่ยวกับภาษาไทย ของ phpBB3'
 	),
 	array(
-		0 => 'ใครเป็นคนแปลเป็นภาษาไทย?',
-		1 => 'เป็นความร่วมมือของ Webmaster <a href="http://www.mindphp.com">Mindphp.com </a> และ <a href="http://www.phpbbthailand.com/"> phpBBThailand.com </a> โดยทาง <a href="http://www.mindphp.com">Mindphp.com </a> ได้เป็นผู้ออกงบประมาณในการจ้างแปล (ใครต้องการช่วยสนับสนุนค่าแปลเชิญที่<a href="http://www.mindphp.com">Mindphp.com </a>) และทาง <a href="http://www.phpbbthailand.com/"> phpBBThailand.com </a> เป็นผู้รวบรวม ช่วยแปลเพิ่มเติมในส่วนที่ คนรับจ้างแปลให้ไม่ถูกต้องตามความเข้าใจ ช่วยตรวจทาน และทำให้ phpBB3 เหมาะกับภาษาไทยให้มากที่สุด '
+		0 => 'ใครเป็นคนแปลภาษาไทยให้กับ phpBB3?',
+		1 => 'เป็นความร่วมมือของ Webmaster <a href="http://www.mindphp.com" target="_bank" title="บทความสอน php Mysql">Mindphp.com </a> และ <a href="http://www.phpbbthailand.com/" target="_bank" title="สอบถามปัญหาการใช้งาน phpBB3"> phpBBThailand.com </a> โดยทาง Mindphp.com ได้เป็นผู้ออกงบประมาณในการจ้างแปล (ใครต้องการช่วยสนับสนุนเชิญที่<a href="http://www.mindphp.com/forums/viewforum.php?f=6">Mindphp.com </a>) และทาง <a href="http://www.phpbbthailand.com/"> phpBBThailand.com </a> เป็นผู้รวบรวม ช่วยแปลเพิ่มเติมเพื่อความให้ใช้คำอธิบายให้เข้าใจง่ายขึ้น ช่วยตรวจทาน และทำให้ phpBB3 เหมาะกับภาษาไทยให้มากที่สุด '
 	),
+        array(
+                0=>'ไม่ได้เรียนมาทางสายคอมพิวเตอร์สามารถใช้ phpBB3 ได้ไหม?',
+                1=>'ไม่ได้เรียนทางสายคอมพิวเตอร์มาโดยตรงก็สามารถติดตั้งและดูแลบริหารเว็บบอร์ดได้ แต่ท่านควรศึกษาหา<a href="http://www.mindphp.com/%E0%B8%84%E0%B8%B9%E0%B9%88%E0%B8%A1%E0%B8%B7%E0%B8%AD/73-%E0%B8%84%E0%B8%B7%E0%B8%AD%E0%B8%AD%E0%B8%B0%E0%B9%84%E0%B8%A3.html" target="_bank" title="ความรู้เกี่ยวกับคำศัพท์">ความรู้เกี่ยวกับคำศัพท์</a> ความรู้คอมพิวเตอร์พื้นฐานเพิ่มเติม',
+        ),
 	array(
 		0 => 'จะสอบถามปัญหาการใช้งาน ภาษาไทยได้ที่ไหน?',
-		1 => 'สามารถ สอบถามปัญหาการใช้งาน phpBB3 ได้ที่ <a href="http://www.phpbbthailand.com/"> phpBBThailand.com </a> ที่นี่มีคำถามและสมาชิกที่ใช้ phpBB3 อยู่มากมาย'
+		1 => 'สามารถ สอบถามปัญหาการใช้งาน phpBB3 ได้ที่ <a href="http://www.phpbbthailand.com/" target="_bank" title="สอบถามปัญหาการใช้งาน phpBB3"> phpBBThailand.com </a> ที่นี่มีคำถามและสมาชิกที่ใช้ phpBB3 อยู่มากมาย'
 	)			
 );
 
