@@ -1,8 +1,7 @@
 <?php
 /** 
-* ภาษาไทย เวอร์ชั่น 1.2.2 
-* for phpbb 3.0.8
-* 05/06/2553 
+* ภาษาไทย เวอร์ชั่น 1.3.2 
+* 06/01/2555
 * ไฟล์ภาษาไทยสำหรับ PHPBB3 โดย www.mindphp.com และ www.phpbbthailand.com
 * posting [Thai]
 */ 
@@ -34,7 +33,7 @@ $lang = array_merge($lang, array(
 	'BBCODE_A_HELP'				=> 'อัพโหลดไฟล์แนป: [attachment=]filename.ext[/attachment]',
 	'BBCODE_B_HELP'				=> 'ข้อความตัวหนา: [b]text[/b]',
 	'BBCODE_C_HELP'				=> 'แสดงข้อความเป็นโค้ด: [code]code[/code]',
-	'BBCODE_E_HELP'				=> 'เพิ่มการแสดงเป็นลิส',
+	'BBCODE_D_HELP'				=> 'Flash: [flash=width,height]http://url[/flash]',
 	'BBCODE_F_HELP'				=> 'ขนาดตัวอักษร: [size=x-small]small text[/size]',
 	'BBCODE_IS_OFF'				=> '%sBBCode%s <em>ปิด</em>',
 	'BBCODE_IS_ON'				=> '%sBBCode%s <em>เปิด</em>',
@@ -47,7 +46,7 @@ $lang = array_merge($lang, array(
 	'BBCODE_S_HELP'				=> 'สีตัวอักษร: [color=red]text[/color]  สามารถใช้โค้ดสี  #FF0000 ได้',
 	'BBCODE_U_HELP'				=> 'ขีดเส้นใต้ข้อความ: [u]text[/u]',
 	'BBCODE_W_HELP'				=> 'ใส่ URL: [url]http://url[/url] or [url=http://url]URL text[/url]',
-	'BBCODE_D_HELP'				=> 'ใส่ Flash: [flash=ความกว้าง,ความสูง]http://url[/flash]',
+	'BBCODE_Y_HELP'				=> 'ลิส: เพิ่มองค์ประกอบของรายการ',
 	'BUMP_ERROR'				=> 'คุณไม่สามารถ bump กระทู้นี้ได้ทันทีหลังจากการโพสต์ครั้งสุดท้าย',
 
 	'CANNOT_DELETE_REPLIED'		=> 'คุณสามารถลบโพสต์ที่ยังไม่ได้มีการตอบกลับเท่านั้น',
