@@ -1,7 +1,7 @@
 <?php
 /** 
-* ภาษาไทย เวอร์ชั่น 1.2.3 
-* 27/07/2553 
+* ภาษาไทย เวอร์ชั่น 1.3.3 
+* 06/01/25535 
 * ไฟล์ภาษาไทยสำหรับ PHPBB3 โดย www.mindphp.com และ www.phpbbthailand.com
 *
 */ 
@@ -142,6 +142,7 @@ $lang = array_merge($lang, array(
 	'CURRENT_IMAGE'				=> 'รูปภาพที่คุณใช้อยู่',
 	'CURRENT_PASSWORD'			=> 'รหัสผ่านปัจจุบัน',
 	'CURRENT_PASSWORD_EXPLAIN'	=> 'คุณต้องใส่รหัสผ่านปัจจุบันของคุณทุกครั้ง ที่มีการเปลี่ยนแปลง ชื่อผู้ใช้งาน อีเมล์ และรหัสผ่าน',
+	'CUR_PASSWORD_EMPTY'		=> 'คุณยังไม่ได้กรอกรหัสผ่าน.',
 	'CUR_PASSWORD_ERROR'		=> 'คุณใส่รหัสผ่านปัจจุบันไม่ถูกต้อง.',
 	'CUSTOM_DATEFORMAT'			=> 'ตั้งค่าเอง…',
 
@@ -241,6 +242,7 @@ $lang = array_merge($lang, array(
 	'INVALID_USER_BIRTHDAY'			=> 'วันเกิดป้อนไม่ถูกต้อง วันที่ผิดพลาด.',	
 	'INVALID_CHARS_USERNAME'	=> 'ในชื่อผู้ใช้มีตัวอักษรที่ไม่ได้รับอนุญาตให้ใช้',
 	'INVALID_CHARS_NEW_PASSWORD'=> 'รหัสผ่านประกอบด้วยตัวอักษรที่ไม่ได้รับอนุญาตให้ใช้',
+	'NEW_PASSWORD_CONFIRM_EMPTY'	=> 'คุุณยังไม่ได้กรอก confirm password.',
 	'ITEMS_REQUIRED'			=> 'ข้อมูลที่ระบุเครื่องหมาย  * เป็นข้อมูลที่จำเป็นต้องกรอก',
 
 	'JOIN_SELECTED'				=> 'ขอเข้าร่วมกลุ่ม',
@@ -274,6 +276,7 @@ $lang = array_merge($lang, array(
 	'MOVE_PM_ERROR'					=> 'เกิดข้อผิดพลาดขณะย้ายข้อความเข้าโฟลเดอร์ใหม่ เพียง %1d จาก %2d ที่คุณต้องการย้าย.',
 	'MOVE_TO_FOLDER'				=> 'ย้ายไปยังโฟล์เดอร์',
 	'MOVE_UP'						=> 'เลื่อนขึ้น',
+	'NEW_EMAIL_CONFIRM_EMPTY'		=> 'คุณยังไม่ได้กรอก a confirm e-mail .',
 
 	'NEW_EMAIL_ERROR'				=> 'อีเมล์ยืนยันไม่ตรงกัน โปรดตรวจสอบอีกครั้ง',
 	'NEW_FOLDER_NAME'				=> 'ชื่อโฟล์เดอร์',
@@ -281,7 +284,7 @@ $lang = array_merge($lang, array(
 	'NEW_PASSWORD_ERROR'			=> 'รหัสผ่านยืนยัน ไม่ตรงกันโปรดตรวจสอบอีกครั้ง',
 	'NOTIFY_METHOD'					=> 'วิธีการแจ้ง',
 	'NOTIFY_METHOD_BOTH'			=> 'ทั้งสอง',
-	'NOTIFY_METHOD_EMAIL'			=> 'E-mailอย่างเดียว',
+	'NOTIFY_METHOD_EMAIL'			=> 'E-mail อย่างเดียว',
 	'NOTIFY_METHOD_EXPLAIN'			=> 'วิธีการส่งเป็นข้อความในบอร์ด',
 	'NOTIFY_METHOD_IM'				=> 'Jabber only',
 	'NOTIFY_ON_PM'					=> 'แจ้งเตือนเมื่อมีข้อความส่วนตัวมาใหม่',
